#!/usr/bin/env bash

DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

NUXEO_CONF=${DIR}/nuxeo.conf
PI_NUXEO_XML=${DIR}/pi-nuxeo.xml
LOG4J_XML=${DIR}/log4j.xml
NGINX_CONF=${DIR}/nginx_dms.conf

source ${DIR}/../../config/dms.conf
source ${DIR}/../../config/storage.conf

DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

# check necessary variables are set
check_variable_set "PATRICIA_DB_DRIVER" "com.microsoft.sqlserver.jdbc.SQLServerDriver"
check_variable_set "PATRICIA_DB_URL"
check_variable_set "PATRICIA_DB_USERNAME"
check_variable_set "PATRICIA_DB_PASSWORD"
check_variable_set "NUXEO_URL"
check_variable_set "PATRICIA_INSTALLATION_ID"
check_variable_set "CLIENT_NAME"
check_variable_set "NUXEO_USER"
check_variable_set "NUXEO_PASSWORD"
check_variable_set "LOG_LEVEL"

# check legacy XMX/XMS variables and apply to NX_XMX/NX_XMS if set old stlye
if [ -n "${XMX}" ]; then
  NX_XMX=$XMX
  NX_XMS=$XMX
fi

if [ -z "${DISABLE_NXP_LOGS}" ]; then
  DISABLE_NXP_LOGS=false
fi

# check new memory settings variables
check_variable_set "NX_XMX" "4096m"
NX_XMS=$NX_XMX
check_variable_set "CB_XMX" "1024m"
CB_XMS=$CB_XMX
# build pi_nuxeo.xml
function create_pi_nuxeo_xml {
  echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>
<!DOCTYPE properties SYSTEM \"http://java.sun.com/dtd/properties.dtd\">
<properties version=\"1.0\">
<!-- Patricia JDBC settings -->
<entry key=\"patricia.jdbc.driver\">${PATRICIA_DB_DRIVER}</entry>
<entry key=\"patricia.jdbc.url\">${PATRICIA_DB_URL}</entry>
<entry key=\"patricia.jdbc.username\">${PATRICIA_DB_USERNAME}</entry>
<entry key=\"patricia.jdbc.password\">${PATRICIA_DB_PASSWORD}</entry>
<entry key=\"nuxeo.server\">${NUXEO_URL}</entry>
<entry key=\"nuxeo.user\">${NUXEO_USER}</entry>
<entry key=\"nuxeo.password\">${NUXEO_PASSWORD}</entry>
<entry key=\"patricia.installation.id\">${PATRICIA_INSTALLATION_ID}</entry>" > ${PI_NUXEO_XML}

if [ -n "$SSO_STATIC_PASS" ]; then
  echo "<entry key=\"sso.mode.enabled\">true</entry>
  <entry key=\"sso.static.pass\">${SSO_STATIC_PASS}</entry>" >> ${PI_NUXEO_XML}
fi

if [ -n "$PROXY_AUTHENTICATED_ADDRESS" ]; then
  echo " <entry key=\"nuxeo.server.for.user\">${PROXY_AUTHENTICATED_ADDRESS}</entry>" >> ${PI_NUXEO_XML}
fi

  echo "</properties>" >> ${PI_NUXEO_XML}
}

# build nuxeo.conf
function create_nuxeo_conf {
echo "JAVA_OPTS=\$JAVA_OPTS -Xms${NX_XMS} -Xmx${NX_XMX}
patricia.db.jdbcDriver=${PATRICIA_DB_DRIVER}
patricia.db.jdbcUrl=${PATRICIA_DB_URL}
patricia.db.username=${PATRICIA_DB_USERNAME}
patricia.db.password=${PATRICIA_DB_PASSWORD}
nuxeo.disable.audit=${DISABLE_NXP_LOGS}" > ${NUXEO_CONF}

if [ -n "$CUSTOM_PARAMETERS" ]; then
  echo "${CUSTOM_PARAMETERS}" >> ${NUXEO_CONF}
fi

if [[ $RUN_IN_DEBUG == "true" ]]; then
  echo "JAVA_OPTS=\$JAVA_OPTS -Xdebug -Xrunjdwp:transport=dt_socket,address=8787,server=y,suspend=n" >> ${NUXEO_CONF}
fi

if [[ $ENABLE_HTTPS == "true" ]]; then
  echo "nuxeo.templates=postgresql,drive,https,pi-nx-repository
        nuxeo.server.http.port=8180
        nuxeo.server.https.port=8080
        nuxeo.server.https.keystoreFile=/home/nuxeo/.keystore
        nuxeo.server.https.keystorePass=${HTTPS_KEY_PASSWORD}" >> ${NUXEO_CONF}
fi

if [ -n "$COUNTRY" ]; then
  echo "JAVA_OPTS=\$JAVA_OPTS -Duser.country=${COUNTRY}" >> ${NUXEO_CONF}
fi

if [ -n "$LANGUAGE" ]; then
  echo "JAVA_OPTS=\$JAVA_OPTS -Duser.language=${LANGUAGE}" >> ${NUXEO_CONF}
fi
}

function create_nginx_conf {
cp ${DIR}/../conf_templates/nginx_dms.conf.template ${NGINX_CONF}
if [[ ${USE_LETSENCRYPT_CERT} != true ]]
then
  sed -i '/ssl_trusted_certificate/d' ${NGINX_CONF}
fi
}

function add_postbox_https_config {
  if [ "$(grep -c postbox /storage/nginx/nginx_dms.conf)" == 0 ]; then
    sed -i '$ d' /storage/nginx/nginx_dms.conf
    echo "    location  /postbox/ {
        proxy_pass http://postbox:9083/postbox/;
        proxy_set_header Host \$host;
        proxy_set_header X-Forwarded-Host \$host;
        proxy_set_header X-Forwarded-Server \$host;
        proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
        proxy_set_header X-Real-IP  \$remote_addr;
    }" >> /storage/nginx/nginx_dms.conf
    echo '}' >> /storage/nginx/nginx_dms.conf
  fi
}

function remove_postbox_https_config {
   if grep -q postbox /storage/nginx/nginx_dms.conf; then
     sed -i -e '/location  \/postbox\//,+7d' /storage/nginx/nginx_dms.conf
   fi
}

function set_log_level {
cp ${DIR}/../conf_templates/log4j.xml.template ${LOG4J_XML}
sed -i -- 's/DMS_LOG_LEVEL/'${LOG_LEVEL}'/g' ${LOG4J_XML}
}

create_pi_nuxeo_xml
create_nuxeo_conf
set_log_level

sudo rsync --remove-source-files ${NUXEO_CONF} ${NUXEO_CONFDIR}"/"
sudo rsync --remove-source-files ${PI_NUXEO_XML} ${NUXEO_CONFDIR}"/"
sudo rsync --remove-source-files ${LOG4J_XML} ${NUXEO_CONFDIR}"/"

sudo chown -R ${USER:=$(/usr/bin/id -run)}:$USER ${NUXEO_CONFDIR}

if [ -e ${NGINX_CONFDIR}/nginx_dms.conf ]
then
    echo "Nginx configuration exists - not replacing with default configuration!"
else
    create_nginx_conf
    sudo rsync --remove-source-files ${NGINX_CONF} ${NGINX_CONFDIR}"/"
    sudo chown -R ${USER:=$(/usr/bin/id -run)}:$USER ${NGINX_CONFDIR}
fi

if [ -n "$HTTPS_CERTIFICATE_PASSWORD" ]
then
  echo "$HTTPS_CERTIFICATE_PASSWORD" > ${DATADIR}/nginx/https_key_password
else
  echo "" > ${DATADIR}/nginx/https_key_password
fi

if [[ ${HTTPS_ENABLED} = true ]]
then
  if [[ ${START_POSTBOX} != true ]]
  then
    remove_postbox_https_config
  else
    add_postbox_https_config
  fi
fi
