#!/usr/bin/env bash

DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
FIREWALL_RELOAD_COMMAND="firewall-cmd --reload"
DMS_PORT1="8080"
DMS_PORT2="9080"
DMS_PORT3="9083"

source ${DIR}/../../deploy_script/default/containers.conf
source ${DIR}/../../config/containers.conf
source ${DIR}/../../config/dms.conf

# Check if network exists and, if so, exit
CHECK_NETWORK_EXISTS_COMMAND=`docker network ls \
	| grep $NETWORK_NAME \
	| wc -l`
eval NETWORK_EXISTS=${CHECK_NETWORK_EXISTS_COMMAND}

if [ ${NETWORK_EXISTS} = "0" ]
then
	# Create docker network first
	NETWORK_COMMAND="docker network create \
		--driver=$NETWORK_DRIVER \
		$NETWORK_NAME"
	eval ${NETWORK_COMMAND}
	echo "Docker network '${NETWORK_NAME}' created"
fi

if [ -e /etc/centos-release ]
then
  if [ -e /etc/firewalld/zones/trusted.xml ]
  then
    # Obtain network ID
    CHECK_NETWORK_ID_COMMAND=`docker network ls \
      | grep $NETWORK_NAME \
      | awk '{print \$1}'`
    eval NETWORK_ID=${CHECK_NETWORK_ID_COMMAND}
    echo "Docker network '${NETWORK_NAME}' has ID ${NETWORK_ID}"

    # Check if interface already in trused networks - if not, add
    CHECK_INTERFACE_COMMAND=`firewall-cmd --zone=trusted --list-interfaces \
      | grep $NETWORK_ID`
    eval INTERFACE_EXISTS=${CHECK_INTERFACE_COMMAND}

    if [ -z "$INTERFACE_EXISTS" ]
    then
      # Set firewalld rule to trust our docker network and allow external connections
      echo "'trusted'-zone existing but docker network interface not assigned"
      LINE_NUM="$(sed -n '/ACCEPT/=' /etc/firewalld/zones/trusted.xml)"
      IF_LINE_NUM=$(($LINE_NUM+1))
      FIREWALLD_ADDTRUSTED_COMMAND="sed -i '${IF_LINE_NUM}i<interface name=\"br-$NETWORK_ID\"/>' /etc/firewalld/zones/trusted.xml"
      eval ${FIREWALLD_ADDTRUSTED_COMMAND}
      echo "Assigned interface ID ${NETWORK_ID} to trusted networks"
    else
      echo "'trusted'-zone existing and docker network interface assigned to it"
    fi
  fi

  if [[ ${HTTPS_ENABLED} = true ]]
  then
    DMS_PORT1="80"
    DMS_PORT2="443"
  fi

  # Check if services on ports 1 and 2 (http: 8080 and 9080) or (https: 80 and 443) are publically available
  CHECK_PORT1_COMMAND=`firewall-cmd --zone=public --list-ports \
    | grep -c ${DMS_PORT1}`
  CHECK_PORT2_COMMAND=`firewall-cmd --zone=public --list-ports \
    | grep -c ${DMS_PORT2}`
  CHECK_PORT3_COMMAND=`firewall-cmd --zone=public --list-ports \
    | grep -c ${DMS_PORT3}`

  eval PORT1_EXISTS=${CHECK_PORT1_COMMAND}
  eval PORT2_EXISTS=${CHECK_PORT2_COMMAND}
  eval PORT3_EXISTS=${CHECK_PORT3_COMMAND}

  if [ "${PORT1_EXISTS}" -eq "0" ]
  then
    # Port 1 not existing - add to public zone
    echo "Port ${DMS_PORT1} not added to public zone. Allowing port ${DMS_PORT1} for public network access"
    FIREWALLD_ADDPORT1_COMMAND="firewall-cmd --zone=public --add-port=${DMS_PORT1}/tcp --permanent"
    eval ${FIREWALLD_ADDPORT1_COMMAND}
  else
    echo "Port ${DMS_PORT1} already added to puclic zone"
  fi

  if [ "${PORT2_EXISTS}" -eq "0" ]
  then
    # Port 2 not existing - add to public zone
    echo "Port ${DMS_PORT2} not added to public zone. Allowing port ${DMS_PORT2} for public network access"
    FIREWALLD_ADDPORT2_COMMAND="firewall-cmd --zone=public --add-port=${DMS_PORT2}/tcp --permanent"
    eval ${FIREWALLD_ADDPORT2_COMMAND}
  else
    echo "Port ${DMS_PORT2} already added to puclic zone"
  fi
  
  if [ "${PORT3_EXISTS}" -eq "0" ]
  then
    # Port 3 not existing - add to public zone
    echo "Port ${DMS_PORT3} not added to public zone. Allowing port ${DMS_PORT3} for public network access"
    FIREWALLD_ADDPORT3_COMMAND="firewall-cmd --zone=public --add-port=${DMS_PORT3}/tcp --permanent"
    eval ${FIREWALLD_ADDPORT3_COMMAND}
  else
    echo "Port ${DMS_PORT3} already added to puclic zone"
  fi

  sleep 3
  echo "Restarting firewalld"
  eval ${FIREWALL_RELOAD_COMMAND}

  firewall-cmd --permanent --zone=public --add-rich-rule='rule family=ipv4 source address=172.17.0.0/16 accept' && firewall-cmd --reload
  firewall-cmd --permanent --zone=public --add-rich-rule='rule family=ipv4 source address=172.18.0.0/16 accept' && firewall-cmd --reload
  firewall-cmd --permanent --zone=public --add-rich-rule='rule family=ipv4 source address=172.19.0.0/16 accept' && firewall-cmd --reload
fi