#!/usr/bin/env bash

DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

POSTFIX_NUXEO_CONFIG=${DIR}/../../config/nuxeo_config.py
POSTFIX_CONFIG=${DIR}/../../config/postfix-config.sh

source ${DIR}/../../config/dms.conf
source ${DIR}/../../config/storage.conf

function check_variable_set {
if [ -z "$1" ]; then
  echo "One of the required variables is not set"
  exit 1
fi
}
if [[ ${HTTPS_ENABLED} = true ]]
then
  POSTFIX_NUXEO_URL="https://${NUXEO_URL}"
else
  POSTFIX_NUXEO_URL="http://${NUXEO_URL}"
fi

if [ -n "$POSTFIX_CUSTOM_NUXEO_ADDRESS" ]; then
  POSTFIX_NUXEO_URL=${POSTFIX_CUSTOM_NUXEO_ADDRESS}
fi

function create_postfix_nuxeo_config {
  echo "#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = 'jiakuanwang'

config = {
    \"rest-url\": \"${POSTFIX_NUXEO_URL}/nuxeo/site/automation/SaveEmailOperation\",
    \"rest-username\": \"${NUXEO_USER}\",
    \"rest-password\": \"${NUXEO_PASSWORD}\",
    \"patricia-installation-id\": ${PATRICIA_INSTALLATION_ID}
}" >> ${POSTFIX_NUXEO_CONFIG}
}

check_variable_set ${PATRICIA_INSTALLATION_ID}
check_variable_set ${NUXEO_USER}
check_variable_set ${NUXEO_PASSWORD}

if [ ! -f ${POSTFIX_CONFIG} ]; then
  echo "${POSTFIX_CONFIG} is not provided"
  exit 1
fi

create_postfix_nuxeo_config

sudo mkdir -p ${POSTFIX_CONFDIR}

sudo rsync --remove-source-files ${POSTFIX_NUXEO_CONFIG} ${POSTFIX_CONFDIR}"/"
sudo rsync ${POSTFIX_CONFIG} ${POSTFIX_CONFDIR}"/"

sudo chown -R ${USER:=$(/usr/bin/id -run)}:$USER ${POSTFIX_CONFDIR}

if [ -n "$POSTFIX_TEMPDIR" ]; then
  sudo mkdir -p ${POSTFIX_TEMPDIR}
  sudo chown -R 1000:1000 ${POSTFIX_TEMPDIR}
fi